#!/usr/bin/python

# mySSUS: my Simple Short URL Service
# Hans-Georg Esser <h.g.esser *AT* gmx.de>
# v0.1  -- 2010/09/25

""" 
see readme.html for english documentation

Der Short URL Service funktioniert wie folgt:

- Benutzer ruft Seite mit URL der Form ezlx.de/a1k12 auf
- Zerlegung a1k12
    a: 2010
    1: Heft 01   (also Ausgabe 01/2010)
    k: Artikel "k"
   12: URL Nr. 12 in Artikel "k"
- Oeffne Datei a1.dat (enthaelt alle URLs zu dieser Ausgabe)
- Suche nach Short URL a1k12 und Mapping
- erzeuge Redirect

Wenn es keinen Eintrag gibt:
- a1k12 "gueltiges" Anfangsstueck a1: Zeige alle URLs dieser Ausgabe
- kein gueltiges Anfangsstueck: Zeige allgemeinen Hinweis
- jedenfalls kein Redirect ohne richtige Short URL

Benutzerdefinierbare Variablen:
- header1
- header2
- footer
- usagemessage
- separator (default: tab, \t)
"""


from sys import argv
from os import environ

header1 = """\
Content-Type: text/html; charset=iso-8859-1

<html>
<head>
<title>EasyLinux-Short-URL-Service</title>"""

header2 = """\
</head>
<body>
<img src="easylinux-logo_154px.png" align="right">
<h1>EasyLinux-Short-URL-Service</h1>
"""

footer = """\
<br>
<hr>
<small><font color="gray">Powered by 
<a href="http://hgesser.de/software/myssus/">mySSUS</a>,
my Simple Short URL Service, &copy; 2010 Hans-Georg Esser</font></small>
</body>
</html>
"""

usagemessage = """\
<p>Willkommen bei unserem Short-URL-Service. Geben Sie eine Adresse der Form
<pre>ezlx.de/a2f5</pre>
ein, damit wir Sie zur richtigen Adresse weiterleiten koennen. Alternativ koennen 
Sie auch eine Adresse wie 
<pre>ezlx.de/a4</pre>
eingeben, um eine Liste aller Links aus einer bestimmten Ausgabe zu sehen 
(z. B. a4 = EL 04/2010).</p>
<p>Hier geht es zur 
<a href="http://www.easylinux.de">Startseite von EasyLinux (easylinux.de)</a>.</p>
"""

separator = "\t"

d = {}

print header1

if "SCRIPT_URL" in environ.keys():
  url = environ["SCRIPT_URL"]
  try:
    url = url[1:]
  except:
    url = "ERROR"
else:
  url = "ERROR"


try:
  ausgabe = url[0:2]
  urlfile = ausgabe+".dat"
  lines = open(urlfile,"r").readlines()
  for l in lines:
    l = l[:-1]
    if l != "":
      short,long = l.split(separator)
      d[short] = long
except:
  url = "ERROR"

if len(url)>3 and d.has_key(url):
  longurl = d[url]
else:
  longurl = "LIST"


if (url != "ERROR") and (longurl != "LIST"):
  # create redirect
  print '<meta http-equiv="refresh" content="2;'+longurl+'">'


print header2

if url == "ERROR":
  print usagemessage

if (url != "ERROR") and (longurl != "LIST"):
  print "<p>Weiterleitung von ezlx.de/" + url + " nach " + longurl + " in 2 Sekunden."

if (url != "ERROR") and (longurl == "LIST"):

  if len(url)>2: print "<p>Sie haben eine Short URL eingegeben, die das System nicht kennt.</p>"

  print "<p>Links aus " + d[ausgabe] + ":</p>\n<ul>"
  keys = d.keys()
  keys.sort()
  for i in keys:
    if len(i)==3:
      # Artikel-Header
      print '<li><b>%s: &nbsp;%s</b>' % (i,d[i])
    if len(i)>3:
      print '<li><b>%s:</b> <a href="%s">%s</a>' % (i,d[i],d[i])
  print "</ul>"


print footer


